import 'package:flutter/material.dart';
import 'package:liftmanager/internal/repair/provider/repair_page_provider.dart';
import 'package:liftmanager/internal/yearly/model/yearly_count_item.dart';
import 'package:liftmanager/internal/yearly/widgets/yearly_list.dart';
import 'package:liftmanager/net/api_service.dart';
import 'package:liftmanager/res/resources.dart';
import 'package:liftmanager/routers/fluro_navigator.dart';
import 'package:liftmanager/utils/theme_utils.dart';
import 'package:liftmanager/utils/toast.dart';
import 'package:liftmanager/widgets/app_bar.dart';
import 'package:provider/provider.dart' as p;

class YearlyListPage extends StatefulWidget {
  YearlyListPage({this.topInto = false});

  final bool topInto;

  @override
  YearlyListPageState createState() => YearlyListPageState();
}

class YearlyListPageState extends State<YearlyListPage>
    with SingleTickerProviderStateMixin, AutomaticKeepAliveClientMixin {
  RepairPageProvider provider = RepairPageProvider();

  TabController _tabController;
  PageController _pageController = PageController(initialPage: 0);
  YearlyCountItem countItem = YearlyCountItem();

  @override
  void initState() {
    super.initState();
    _tabController = new TabController(vsync: this, length: 3);
//    if (widget.topInto) {
//      _tabController.animateTo(1);
//      _pageController = PageController(initialPage: 1);
//    } else {
      _pageController = PageController(initialPage: 0);
//    }
    getCount();
  }

  getCount() {
    ApiService(context: context).yearlyCount(onSuccess: (res) {
      if (res != null) {
        countItem = res;
        setState(() {});
      }
    }, onError: (code, msg) {
      toasts(msg);
    });
  }

  @override
  void dispose() {
    _tabController.dispose();
    super.dispose();
  }

  _onPageChange(int index) {
    _tabController.animateTo(index);
    provider.setIndex(index);
    getCount();
  }

  @override
  Widget build(BuildContext context) {
    return p.ChangeNotifierProvider<RepairPageProvider>(
        create: (_) => provider,
        child: WillPopScope(
          onWillPop: () {
            NavigatorUtils.goBackWithParams(context, true);
            return Future.value(false);
          },
          child: Scaffold(
            appBar: MyAppBar(
              centerTitle: "年检管理",
            ),
            body: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                Container(
                  // 隐藏点击效果
                  color: ThemeUtils.getTabsBg(context),
                  child: TabBar(
                    onTap: (index) {
                      if (!mounted) {
                        return;
                      }
                      _pageController.jumpToPage(index);
                    },
                    isScrollable: false,
                    controller: _tabController,
                    labelStyle: TextStyles.textBold18,
                    indicatorSize: TabBarIndicatorSize.label,
                labelPadding: const EdgeInsets.all(0),
                    unselectedLabelColor: Colours.text_gray,
                    labelColor: Theme.of(context).primaryColor,
                    indicatorPadding: EdgeInsets.only(left: 20.0, right: 20.0),
                    tabs: <Widget>[
                      _TabView("待开启", "(${countItem.toConfirm})", 0),
                      _TabView("执行中", "(${countItem.processing})", 1),
                      _TabView("已完成", "(${countItem.complete})", 2),
                    ],
                  ),
                ),
                Gaps.line,
                Expanded(
                  child: PageView.builder(
                    key: const Key('pageView'),
                    itemCount: 3,
                    onPageChanged: _onPageChange,
                    controller: _pageController,
                    itemBuilder: (BuildContext context, int index) {
                      return Container(
                          color: ThemeUtils.getBackgroundColor(context),
                          child: YearlyList(
                              index: index,
                              callback: () {
                                getCount();
                              }));
                    },
                  ),
                )
              ],
            ),
          ),
        ));
  }

  @override
  bool get wantKeepAlive => true;
}

class _TabView extends StatelessWidget {
  const _TabView(this.tabName, this.tabSub, this.index);

  final String tabName;
  final String tabSub;
  final int index;

  @override
  Widget build(BuildContext context) {
    return p.Consumer<RepairPageProvider>(
      builder: (_, provider, child) {
        bool isDark = ThemeUtils.isDark(context);
        return Tab(
            child: SizedBox(
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Text(
                tabName,
                style: TextStyle(
                    fontSize: 15,
                    color: isDark ? Colours.dark_text : Colours.text),
              ),
              Padding(
                padding: const EdgeInsets.only(top: 1.0),
                child:
                    Text(tabSub, style: TextStyle(fontSize: Dimens.font_sp12)),
              ),
            ],
          ),
        ));
      },
    );
  }
}
